/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include <config.h>

#include "acache.h"
#include "articlelist.h"
#include "prefs.h"
#include "text.h"
#include "util.h"


Message *
message_dup (const Message *src)
{
	Message * dest       = g_new0 (Message, 1);
	dest->to             = g_strdup (src->to);
	dest->from           = g_strdup (src->from);
	dest->reply_to       = g_strdup (src->reply_to);
	dest->date           = g_strdup (src->date);
	dest->subject        = g_strdup (src->subject);
	dest->body           = g_strdup (src->body);
        dest->references     = g_strdup (src->references);
        dest->newsgroups     = g_strdup (src->newsgroups);
        dest->followup_to    = g_strdup (src->followup_to);
	dest->message_id     = g_strdup (src->message_id);
	dest->type           = src->type;
	dest->window         = src->window;
	dest->needs_window   = src->needs_window;
	return dest;
}

void
message_free (Message * msg)
{
	if (msg != NULL)
	{
		if (msg->rcpts != NULL)
			g_ptr_array_free (msg->rcpts, TRUE);

		g_free (msg->to);
		g_free (msg->from);
		g_free (msg->newsgroups);
		g_free (msg->date);
		g_free (msg->subject);
		g_free (msg->body);
		g_free (msg->references);
		g_free (msg->reply_to);
		g_free (msg->followup_to);
		g_free (msg->message_id);
		g_free (msg);
	}
}


void
message_import_article (Message * msg, const Article * article)
{
	struct tm lcltime;
	gchar date[40];

	g_return_if_fail (article!=NULL);

	/* calculate the posting time */
	localtime_r (&article->date, &lcltime);
	strftime (date, sizeof(date), "%A, %B %e, %Y %l:%M %p", &lcltime);

	replace_gstr (&msg->date,        g_strdup(date));
	replace_gstr (&msg->from,        g_strdup(article->author));
	replace_gstr (&msg->subject,     g_strdup(article->subject));
	replace_gstr (&msg->reply_to,    g_strdup(article->reply_to));
	replace_gstr (&msg->references,  g_strdup(article->references));
	replace_gstr (&msg->message_id,  g_strdup(article->message_id));
	replace_gstr (&msg->newsgroups,  g_strdup(article->newsgroups));
	replace_gstr (&msg->followup_to, g_strdup(article->followup_to));
	replace_gstr (&msg->body,        acache_load_body(article->message_id));
}


/*---[ message_new ]--------------------------------------------------
 *
 *--------------------------------------------------------------------*/
Message*
message_new (Article *article)
{
	Message *msg;
	struct tm *lcltime;
	gchar date[40];

	g_return_val_if_fail (article!=NULL, NULL);

	msg = g_new0 (Message, 1);
	msg->group = article->group;
	msg->server = article->group->server;

	/* FIXME msg->to = g_strdup (Pan.active_group->name); */
	msg->from = g_strdup (article->author);
	lcltime = localtime (&article->date);
	strftime (date, 40, "%A, %B %e, %Y %l:%M %p", lcltime);
	msg->date = g_strdup (date);
	msg->subject = g_strdup (article->subject);
	msg->message_id = g_strdup (article->message_id);
	msg->body = acache_load_body (article->message_id);
	msg->reply_to = g_strdup (article->reply_to);
	msg->followup_to = g_strdup (article->followup_to);
	msg->newsgroups = g_strdup (article->newsgroups);
	msg->references = g_strdup (article->references);
	return msg;
}

Message*
message_new_empty (Server * server)
{
	Message * msg;
	g_return_val_if_fail (server!=NULL, NULL);
	msg = g_new0 (Message, 1);
	msg->server = server;
	return msg;
}

void
message_get_attribution_string (const Message *msg,
                                GString * setme)
{
	g_string_truncate (setme, 0);

	if (is_nonempty_string(msg->message_id))
	{
		g_string_assign (setme, attribution_line);
		pan_g_string_replace (setme, "%i", msg->message_id);
		pan_g_string_replace (setme, "%a", msg->from);
		pan_g_string_replace (setme, "%d", msg->date);
	}
}
